General Hecke Algebras and Hecke Modules
========================================

This chapter describes the basic functionality for modules over Hecke
algebras, including decompositions, degeneracy maps and so on. For specific
examples of Hecke algebras that use this functionality see `Modular
Symbols <../modsym/index.html>`_ and `Modular Forms
<../modfrm/index.html>`_.

.. toctree::
   :maxdepth: 1

   sage/modular/hecke/module
   sage/modular/hecke/ambient_module
   sage/modular/hecke/submodule
   sage/modular/hecke/element

   sage/modular/hecke/homspace
   sage/modular/hecke/morphism
   sage/modular/hecke/degenmap

   sage/modular/hecke/algebra
   sage/modular/hecke/hecke_operator

.. include:: ../footer.txt
